@@ -4,7 +4,7 @@ import logging
 
 class TestRefuter(object):
     def __init__(self, error_tolerance, estimator_method, refuter_method,
-            transformations=None, params = None, confounders_effect_on_t=None, 
+            transformations=None, params = None, confounders_effect_on_t=None,
             confounders_effect_on_y=None, effect_strength_on_t=None,
             effect_strength_on_y=None, **kwargs):
         self._error_tolerance = error_tolerance
@@ -17,7 +17,7 @@ class TestRefuter(object):
         self.confounders_effect_on_y = confounders_effect_on_y
         self.effect_strength_on_t = effect_strength_on_t
         self.effect_strength_on_y = effect_strength_on_y
-        
+
         if 'logging_level' in kwargs:
             logging.basicConfig(level=kwargs['logging_level'])
         else:
@@ -28,7 +28,7 @@ class TestRefuter(object):
 
     def null_refutation_test(self, data=None, dataset="linear", beta=10,
             num_common_causes=1, num_instruments=1, num_samples=100000,
-            treatment_is_binary=True):
+            treatment_is_binary=True, num_dummyoutcome_simulations=None):
         # Supports user-provided dataset object
         if data is None:
             data = dowhy.datasets.linear_dataset(beta=beta,
@@ -76,7 +76,7 @@ class TestRefuter(object):
                 effect_strength_on_treatment = 0,
                 effect_strength_on_outcome = 0)
             error = abs(refute.new_effect - ate_estimate.value)
-            
+
             print("Error in refuted estimate = {0} with tolerance {1}%. Estimated={2},After Refutation={3}".format(
                 error, self._error_tolerance * 100, ate_estimate.value, refute.new_effect)
             )
@@ -85,44 +85,44 @@ class TestRefuter(object):
 
         elif self.refuter_method == "placebo_treatment_refuter":
             if treatment_is_binary is True:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                         ate_estimate,
                                         method_name=self.refuter_method,
                                         num_simulations=10
                                         )
             else:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                             ate_estimate,
                                             method_name=self.refuter_method
                                             )
             # This value is hardcoded to be zero as we are runnning this on a linear dataset.
             # Ordinarily, we should expect this value to be zero.
             EXPECTED_PLACEBO_VALUE = 0
-            
+
             error =  abs(ref.new_effect - EXPECTED_PLACEBO_VALUE)
 
-            print("Error in the refuted estimate = {0} with tolerence {1}%. Expected Value={2}, After Refutation={3}".format(
-                error, self._error_tolerance * 100, EXPECTED_PLACEBO_VALUE, ref.new_effect)
+            print("Error in the refuted estimate = {0} with tolerence {1}. Expected Value={2}, After Refutation={3}".format(
+                error, self._error_tolerance, EXPECTED_PLACEBO_VALUE, ref.new_effect)
             )
 
             print(ref)
 
             res = True if (error <  self._error_tolerance) else False
             assert res
-            
+
         elif self.refuter_method == "data_subset_refuter":
             if treatment_is_binary is True:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                         ate_estimate,
                                         method_name=self.refuter_method,
                                         num_simulations=5
                                         )
             else:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                             ate_estimate,
                                             method_name=self.refuter_method
                                             )
-            
+
             error =  abs(ref.new_effect - ate_estimate.value)
 
             print("Error in the refuted estimate = {0} with tolerence {1}%. Estimated={2}, After Refutation={3}".format(
@@ -133,20 +133,20 @@ class TestRefuter(object):
 
             res = True if (error <  abs(ate_estimate.value)*self._error_tolerance) else False
             assert res
-        
+
         elif self.refuter_method == "bootstrap_refuter":
             if treatment_is_binary is True:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                         ate_estimate,
                                         method_name=self.refuter_method,
                                         num_simulations=5
                                         )
             else:
-                ref = model.refute_estimate(target_estimand, 
+                ref = model.refute_estimate(target_estimand,
                                             ate_estimate,
                                             method_name=self.refuter_method
                                             )
-            
+
             error =  abs(ref.new_effect - ate_estimate.value)
 
             print("Error in the refuted estimate = {0} with tolerence {1}%. Estimated={2}, After Refutation={3}".format(
@@ -163,7 +163,7 @@ class TestRefuter(object):
                 ref_list = model.refute_estimate(target_estimand,
                                             ate_estimate,
                                             method_name=self.refuter_method,
-                                            num_simulations = 2
+                                            num_simulations = num_dummyoutcome_simulations
                                             )
             else:
                 ref_list = model.refute_estimate(target_estimand,
@@ -171,7 +171,7 @@ class TestRefuter(object):
                                             method_name=self.refuter_method,
                                             transformation_list = self.transformations,
                                             params = self.params,
-                                            num_simulations = 2
+                                            num_simulations = num_dummyoutcome_simulations
                                             )
 
             INDEX = 0
@@ -183,27 +183,36 @@ class TestRefuter(object):
 
             error = abs( ref.new_effect - EXPECTED_DUMMY_OUTCOME_VALUE)
 
-            print("Error in the refuted estimate = {0} with tolerence {1}%. Expected Value={2}, After Refutation={3}".format(
-                error, self._error_tolerance * 100, EXPECTED_DUMMY_OUTCOME_VALUE, ref.new_effect)
+            print("Error in the refuted estimate = {0} with tolerence {1}. Expected Value={2}, After Refutation={3}".format(
+                error, self._error_tolerance, EXPECTED_DUMMY_OUTCOME_VALUE, ref.new_effect)
             )
 
             print(ref)
-    
-            res = True if (error <  abs(ate_estimate.value)*self._error_tolerance) else False
-            assert res
- 
-    def binary_treatment_testsuite(self, num_samples=100000,num_common_causes=1,tests_to_run="all"):
-        self.null_refutation_test(num_common_causes=num_common_causes,num_samples=num_samples)
-        if tests_to_run != "atleast-one-common-cause":
-            self.null_refutation_test(num_common_causes=0,num_samples=num_samples)
 
-    def continuous_treatment_testsuite(self, num_samples=100000,num_common_causes=1,tests_to_run="all"):
+            res = True if (error <  self._error_tolerance) else False
+            assert res
+
+    def binary_treatment_testsuite(self, num_samples=100000,num_common_causes=1,tests_to_run="all",
+            num_dummyoutcome_simulations=2):
+        self.null_refutation_test(num_common_causes=num_common_causes,
+                num_samples=num_samples,
+                num_dummyoutcome_simulations=num_dummyoutcome_simulations)
+        if tests_to_run != "atleast-one-common-cause":
+            self.null_refutation_test(num_common_causes=0,
+                    num_samples=num_samples,
+                    num_dummyoutcome_simulations=num_dummyoutcome_simulations)
+
+    def continuous_treatment_testsuite(self, num_samples=100000,
+            num_common_causes=1,tests_to_run="all",
+            num_dummyoutcome_simulations=2):
         self.null_refutation_test(
             num_common_causes=num_common_causes,num_samples=num_samples,
-            treatment_is_binary=False)
+            treatment_is_binary=False,
+            num_dummyoutcome_simulations=num_dummyoutcome_simulations)
         if tests_to_run != "atleast-one-common-cause":
             self.null_refutation_test(num_common_causes=0, num_samples=num_samples,
-                    treatment_is_binary=False)
-    
-        
+                    treatment_is_binary=False,
+                    num_dummyoutcome_simulations=num_dummyoutcome_simulations)
+
+
 
